@@ -10,7 +10,9 @@
 #define XDG_DESKTOP_PORTAL_KDE_BACKGROUND_H
 
 #include <QDBusAbstractAdaptor>
+#include <QDBusContext>
 #include <QDBusObjectPath>
+#include <QSet>
 
 namespace KWayland
 {
@@ -20,12 +22,14 @@ class PlasmaWindow;
 }
 }
 
+class KNotification;
+
 class BackgroundPortal : public QDBusAbstractAdaptor
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.freedesktop.impl.portal.Background")
 public:
-    explicit BackgroundPortal(QObject *parent);
+    explicit BackgroundPortal(QObject *parent, QDBusContext *context);
     ~BackgroundPortal() override;
 
     enum ApplicationState {
@@ -43,7 +47,7 @@ public:
     enum NotifyResult {
         Forbid = 0,
         Allow = 1,
-        Ignore = 2,
+        AllowOnce = 2,
     };
 
 public Q_SLOTS:
@@ -62,6 +66,8 @@ private:
     uint m_notificationCounter = 0;
     QList<KWayland::Client::PlasmaWindow *> m_windows;
     QVariantMap m_appStates;
+    QSet<QString> m_backgroundAppWarned;
+    QDBusContext *const m_context;
 };
 Q_DECLARE_OPERATORS_FOR_FLAGS(BackgroundPortal::AutostartFlags)
 
